from setuptools import setup

setup(name='sci-distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['sci-distributions'],
      author='Arohan Ajit',
      zip_safe=False)
